Version 0.5.7 (11.12.2024)
- Added get_orientation_to_volume method to SimultanFace which returns the orientation of the face to the volume

Version 0.5.3 (01.12.2024)
- Added support for directories (Assets and FileInfo)

Version 0.5.1 (25.11.2024)

- setting re-register default in Mapper to True
- added uncache method to utils for monkey patching
